diff mercurial/ui.py @ 47200:b0e92313107e

parselist: move the function from config to stringutil We move the function in a lower level module to avoid cycle. It moves next to `parsebool` who had to migrate for the same reasons. Differential Revision: https://phab.mercurial-scm.org/D10449
author Pierre-Yves David <pierre-yves.david@octobus.net>
date Fri, 16 Apr 2021 01:18:28 +0200
parents 9ea75ea23534
children bcafcd779d2e
line wrap: on
line diff
--- a/mercurial/ui.py	Fri Apr 16 02:14:21 2021 +0200
+++ b/mercurial/ui.py	Fri Apr 16 01:18:28 2021 +0200
@@ -887,10 +887,10 @@
         """
         # default is not always a list
         v = self.configwith(
             config.parselist, section, name, default, b'list', untrusted
         )
         if isinstance(v, bytes):
-            return config.parselist(v)
+            return stringutil.parselist(v)
         elif v is None:
             return []
         return v
@@ -887,10 +887,10 @@
         # default is not always a list
         v = self.configwith(
-            config.parselist, section, name, default, b'list', untrusted
+            stringutil.parselist, section, name, default, b'list', untrusted
         )
         if isinstance(v, bytes):